<?php
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! class_exists( 'BESTBUG_CRYPTO_OPTIONS' ) ) {
	/**
	 * BESTBUG_CRYPTO_OPTIONS Class
	 *
	 * @since	1.0
	 */
	class BESTBUG_CRYPTO_OPTIONS {


		/**
		 * Constructor
		 *
		 * @return	void
		 * @since	1.0
		 */
		function __construct() {
			$this->init();
		}

		public function init() {
			
			add_filter('bb_register_options', array( $this, 'options'), 10, 1 );

			if(is_admin()) {
				add_action( 'admin_enqueue_scripts', array( $this, 'adminEnqueueScripts' ) );
			}
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueueScripts' ) );
			add_action( 'bb_before_save_options', array( $this, 'updateCache' ), 10, 1 );
        }

		public function adminEnqueueScripts() {
			if(isset($_GET['page']) && ($_GET['page'] == BESTBUG_CRYPTO_SLUG || $_GET['page'] == BESTBUG_CRYPTO_SLUG_SETTINGS || $_GET['page'] == BESTBUG_CRYPTO_ALL_REALCRYPTO_SLUG || $_GET['page'] == BESTBUG_CRYPTO_ADD_REALCRYPTO_SLUG)) {
				BESTBUG_CORE_OPTIONS::adminEnqueueScripts();
			}
		}

		public function enqueueScripts() {
		
        }
		
		public function updateCache($options){
			
			// if(!isset($options[BESTBUG_CRYPTO_PREFIX . 'update_cache']) || $options[BESTBUG_CRYPTO_PREFIX . 'update_cache'] == 'no') {
			// 	return;
			// }
			
			BESTBUG_CRYPTO_HELPER::cacheCurrency();
			
		}
        
        public function options($options) {
			if( empty($options) ) {
				$options = array();
			}
			$all_currency = array();
			
			if(isset($_GET['page']) && $_GET['page'] == BESTBUG_CRYPTO_SLUG_SETTINGS) {
				$all_currency = BESTBUG_CRYPTO_HELPER::cacheCurrency();
			}
			
			$prefix = BESTBUG_CRYPTO_PREFIX;
			$options[] = array(
				'type' => 'options_fields',
				//'ajax_action' => BESTBUG_CRYPTO_SAVE_SETTINS,
				'menu' => array(
					// add_submenu_page || add_menu_page
					'type' => 'add_submenu_page',
					'parent_slug' => BESTBUG_CRYPTO_SLUG,
					'page_title' => esc_html('Settings', 'bestbug'),
					'menu_title' => esc_html('Settings', 'bestbug'),
					'capability' => 'manage_options',
					'menu_slug' => BESTBUG_CRYPTO_SLUG_SETTINGS,
				),
				'fields' => array(
					array(
						'type'       => 'toggle',
						'heading'    => esc_html__( 'Show Loading', 'bestbug' ),
						'param_name' => $prefix . 'loading',
						'value'      => 'no',
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => esc_html__( 'Background loading', 'bestbug' ),
						'param_name' => $prefix . 'bg_loading',
						'value'      => 'rgba(0,0,0,0.9)',
						'description' => esc_html__( 'Custom background loading.', 'bestbug' ),
						'dependency'  => array( 'element' => $prefix . 'loading', 'value' => array( 'yes' ) ),
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'API Openexchangerates', 'bestbug' ),
						'param_name' => $prefix . 'openexchangerates',
						'description' => 'Create FREE API Openexchangerates in <a href="https://openexchangerates.org/signup/free" target="_blank">HERE</a>',
						'value'      => '8c4ddb87246a4149a1348fb751a2ac77',
					),
					array(
						'type'        => 'dropdown',
						'heading'     => esc_html__( 'Currency', 'bestbug' ),
						'value'       => $all_currency,
						'param_name'  => $prefix . 'currency',
						'std' => 'USD',
						'description' => esc_html__( 'Choose default currency.', 'bestbug' ),
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Billion symbol', 'bestbug' ),
						'param_name' => $prefix . 'billion_symbol',
						'value'      => 'B',
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Million symbol', 'bestbug' ),
						'param_name' => $prefix . 'million_symbol',
						'value'      => 'M',
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Thousand symbol', 'bestbug' ),
						'param_name' => $prefix . 'thousand_symbol',
						'value'      => 'K',
					),
					array(
						'type'       => 'toggle',
						'heading'    => esc_html__( 'Show sparkchart24h', 'bestbug' ),
						'description' => esc_html__( 'Show sparkchart24h on table.', 'bestbug' ),
						'param_name' => $prefix . 'show_sparkchart24h',
						'value'      => 'yes',
					),
					// array(
					// 	'type'       => 'toggle',
					// 	'heading'    => esc_html__( 'Update cache', 'bestbug' ),
					// 	'param_name' => $prefix . 'update_cache',
					// 	'value'      => 'no',
					// 	'description' => esc_html__( 'Update cache coins after save changes', 'bestbug' ),
					// ),
				),
			);
			
			return $options;
        }
        
    }
	
	new BESTBUG_CRYPTO_OPTIONS();
}

