<?php
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! class_exists( 'BESTBUG_CRYPTO_REALCRYPTO' ) ) {
	/**
	 * BESTBUG_CRYPTO_REALCRYPTO Class
	 *
	 * @since	1.0
	 */
	class BESTBUG_CRYPTO_REALCRYPTO {
		
		public $page_title;
		
		public $orderby;
		public $order;
		
		public $shortcodes;

		/**
		 * Constructor
		 *
		 * @return	void
		 * @since	1.0
		 */
		function __construct() {
			$this->init();
		}

		public function init() {
			
			add_action( 'admin_menu', array( $this, 'all_realcrypto' ) );
			add_filter('bb_register_options', array( $this, 'realcrypto'), 10, 1 );

			if(is_admin()) {
				add_action( 'admin_enqueue_scripts', array( $this, 'adminEnqueueScripts' ) );
			}
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueueScripts' ) );
			add_action( 'wp_ajax_rc_delete_shortcode', array($this, 'delete') );
        }

		public function adminEnqueueScripts() {
			
		}

		public function enqueueScripts() {
		
        }
		
		public function delete(){
			if(isset($_POST['id'])) {
				$del = wp_delete_post( $_POST['id'], true );
				if($del) {
					echo json_encode(array(
						'status' => 'notice',
						'title' => esc_html('Deleted', 'bestbug'),
						'message' => esc_html('Shortcode is deleted!', 'bestbug'),
					));
					exit;
				}
			}
			echo json_encode(array(
				'status' => 'error',
				'title' => esc_html('Error', 'bestbug'),
				'message' => esc_html('Can not delete!', 'bestbug'),
			));
			exit;
		}
		
		public function all_realcrypto(){
			$menu = array(
				'page_title' => esc_html('Ultimate Crypto Widgets Shortcodes', 'bestbug'),
				'menu_title' => esc_html('Ultimate Crypto Widgets', 'bestbug'),
				'capability' => 'manage_options',
				'menu_slug' => BESTBUG_CRYPTO_SLUG,
				'icon' => BESTBUG_CRYPTO_URL . '/assets/admin/images/logo-20x20.png',
				'position' =>  76,
			);
			$this->page_title = $menu['page_title'];
			add_menu_page($menu['page_title'],
						$menu['menu_title'],
						$menu['capability'],
						$menu['menu_slug'],
						array(&$this, 'view'),
						$menu['icon'],
						$menu['position']
					);
			add_submenu_page(
				BESTBUG_CRYPTO_SLUG,
				esc_html__('All Shortcodes' , 'bestbug'),
				esc_html__('All Shortcodes' , 'bestbug'),
				$menu['capability'],
				$menu['menu_slug'],
				array(&$this, 'view')
		    );
		}
		
		public function view() {
			
			$this->shortcodes = get_posts(array(
				'numberposts' => -1,
				'post_type' => BESTBUG_CRYPTO_POSTTYPE,
				'orderby' => $this->orderby,
				'order'   => $this->order,
			));
			
			BESTBUG_HELPER::begin_wrap_html($this->page_title);
			include 'templates/real_crypto.view.php';
			BESTBUG_HELPER::end_wrap_html();
		}
		
		public function sortform(){
			?>
			<div class="bb-row">
			    <div class="bb-col">
			        <a href="<?php echo admin_url( 'admin.php?page=' . BESTBUG_CRYPTO_ADD_REALCRYPTO_SLUG ) ?>" class="button success"><span class="dashicons dashicons-plus-alt"></span><?php esc_html_e('Add Shortcode', 'bestbug') ?></a>
			    </div>
			</div>
			<?php
		}
        
        public function realcrypto($options) {
			if( empty($options) ) {
				$options = array();
			}
			$coins = array();
			
			if(isset($_GET['page']) && $_GET['page'] == BESTBUG_CRYPTO_ADD_REALCRYPTO_SLUG) {
				$coins = BESTBUG_CRYPTO_HELPER::coinList();
			}
			
			$prefix = BESTBUG_CRYPTO_PREFIX;
			
			$general = array(
				array(
					'type'       => 'text',
					'heading'    => esc_html__( 'Shortcode Generate', 'bestbug' ),
					'param_name' => 'shortcode-generate',
					'value'      => (isset($_REQUEST['ID']) && !empty($_REQUEST['ID']))?'['. esc_attr(BESTBUG_CRYPTOCOMPARE_SHORTCODE).' id="'.esc_html($_REQUEST['ID']).'"]':'',
					'description' => esc_html__( 'Copy and paste to any where you want to display', 'bestbug' ),
				),
				array(
					'type'       => 'hidden',
					'param_name' => 'ID',
					'value'      => (isset($_REQUEST['ID']) && !empty($_REQUEST['ID']))?$_REQUEST['ID']:'',
				),
				array(
					'type'       => 'hidden',
					'param_name' => 'post_type',
					'value'      => BESTBUG_CRYPTO_POSTTYPE,
				),
				array(
					'type'       => 'textfield',
					'heading'    => esc_html__( 'Title', 'bestbug' ),
					'param_name' => 'post_title',
					'value'      => '',
				),
				array(
					'type'        => 'dropdown',
					'heading'     => esc_html__( 'Layout', 'bestbug' ),
					'value'       => array(
						'inline' => esc_html__( 'Inline', 'bestbug' ),
						'leaderboard' => esc_html__( 'Leaderboard', 'bestbug' ),
						'spark-charts' => esc_html__( 'Spark charts', 'bestbug' ),
						'table' => esc_html__( 'Table', 'bestbug' ),
						'comparison' => esc_html__( 'Comparison', 'bestbug' ),
						'ticker' => esc_html__( 'Ticker', 'bestbug' ),
						'chart' => esc_html__( 'Chart', 'bestbug' ),
						'box' => esc_html__( 'Box', 'bestbug' ),
						'convert' => esc_html__( 'Convert', 'bestbug' ),
					),
					'param_name'  => $prefix . 'layout',
					'std' => 'table',
					'description' => esc_html__( 'Choose layout to show.', 'bestbug' ),
				),
				array(
					'type'       => 'textfield',
					'heading'    => esc_html__( 'Detail URL', 'bestbug' ),
					'param_name' => $prefix . 'detail_url',
					'description' => esc_html__( 'You can create detail page use all shortcodes.', 'bestbug' ),
					'value'      => '',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'table' ) ),
				),
				array(
					'type'        => 'multi_select',
					'heading'     => esc_html__( 'Choose Coins', 'bestbug' ),
					'value'       => $coins,
					'param_name'  => $prefix . 'only_coins',
					'std' 		  => array(),
					'description' => esc_html__( 'Choose coins to show.', 'bestbug' ),
					'dependency'  => array( 
						'element' => $prefix . 'layout',
						'value' => array( 'inline', 'leaderboard', 'spark-charts', 'comparison', 'ticker', 'chart', 'box'  ) 
					),
				),
				
				array(
					'type'       => 'toggle',
					'heading'    => esc_html__( 'Hight Light', 'bestbug' ),
					'param_name' => $prefix . 'high_light',
					'value'      => 'yes',
					'description' => esc_html__( 'Change color when Price of Coin increase or reduction.', 'bestbug' ),
					'dependency'  => array( 
						'element' => $prefix . 'layout',
						'value' => array( 'inline', 'table', 'leaderboard', 'spark-charts', 'comparison', 'ticker', 'chart', 'box'  ) 
					),
				),
				
				array(
					'type'        => 'dropdown',
					'heading'    => esc_html__( 'Shape', 'bestbug' ),
					'value'       => array(
						'square' => esc_html__( 'Square', 'bestbug' ),
						'round' => esc_html__( 'Round', 'bestbug' ),
						'rounded' => esc_html__( 'Rounded', 'bestbug' ),
					),
					'param_name'  => $prefix . 'shape',
					'std' => 'square',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'box', 'convert', 'spark-charts', 'leaderboard' ) ),
				),
				
				array(
					'type'        => 'dropdown',
					'heading'    => esc_html__( 'Skin', 'bestbug' ),
					'value'       => array(
						'white' => esc_html__( 'White', 'bestbug' ),
						'transparent' => esc_html__( 'Transparent', 'bestbug' ),
						'red' => esc_html__( 'Red', 'bestbug' ),
						'pink' => esc_html__( 'Pink', 'bestbug' ),
						'purple' => esc_html__( 'Purple', 'bestbug' ),
						'deep-purple' => esc_html__( 'Deep Purple', 'bestbug' ),
						'indigo' => esc_html__( 'Indigo', 'bestbug' ),
						'blue' => esc_html__( 'Blue', 'bestbug' ),
						'light-blue' => esc_html__( 'Light Blue', 'bestbug' ),
						'cyan' => esc_html__( 'Cyan', 'bestbug' ),
						'teal' => esc_html__( 'Teal', 'bestbug' ),
						'green' => esc_html__( 'Green', 'bestbug' ),
						'light-green' => esc_html__( 'Light Green', 'bestbug' ),
						'lime' => esc_html__( 'Lime', 'bestbug' ),
						'yellow' => esc_html__( 'Yellow', 'bestbug' ),
						'amber' => esc_html__( 'Amber', 'bestbug' ),
						'orange' => esc_html__( 'Orange', 'bestbug' ),
						'deep-orange' => esc_html__( 'Deep Orange', 'bestbug' ),
						'brown' => esc_html__( 'Brown', 'bestbug' ),
						'grey' => esc_html__( 'Grey', 'bestbug' ),
						'blue-grey' => esc_html__( 'Blue Grey', 'bestbug' ),
					),
					'param_name'  => $prefix . 'skin',
					'std' => 'white',
				),
				array(
					'type'       => 'toggle',
					'heading'    => esc_html__( 'Fill background', 'bestbug' ),
					'param_name' => $prefix . 'fill_background',
					'value'      => 'no',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'box' ) ),
				),
				
				// array(
				// 	'type'       => 'colorpicker',
				// 	'heading'    => esc_html__( 'Main Color', 'bestbug' ),
				// 	'param_name' => $prefix . 'color',
				// 	'value'      => '#000000',
				// 	'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'table', 'comparison' ) ),
				// ),
				// array(
				// 	'type'       => 'colorpicker',
				// 	'heading'    => esc_html__( 'Main Background Color', 'bestbug' ),
				// 	'param_name' => $prefix . 'bgcolor',
				// 	'value'      => '#000000',
				// 	'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'table', 'comparison' ) ),
				// ),
			);
			$inline = array(
				array(
					'type'        => 'checkbox',
					'heading'     => esc_html__( 'Show Fields', 'bestbug' ),
					'value'       => array(
						'icon' => esc_html__( 'Icon', 'bestbug' ),
						'short' => esc_html__( 'Short name', 'bestbug' ),
						'long' => esc_html__( 'Long name', 'bestbug' ),
						'price' => esc_html__( 'Price', 'bestbug' ),
						'change24h' => esc_html__( 'Price change 24h', 'bestbug' ),
						'change24hptc' => esc_html__( 'Percent change 24h', 'bestbug' ),
						'arrow' => esc_html__( 'Arrow', 'bestbug' ),
					),
					'param_name'  => $prefix . 'inline_fields',
					'std' => array(
						'icon' => 1,
						'short' => 1,
						'long' => 1,
						'price' => 1,
						'change24h' => 1,
						'change24hptc' => 1,
						'arrow' => 1,
					),
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'inline', 'ticker' ) ),
					'description' => esc_html__( 'Choose the fields to show.', 'bestbug' ),
				),
			);
			$box = array(
				array(
					'type'        => 'dropdown',
					'heading'    => esc_html__( 'Style', 'bestbug' ),
					'value'       => array(
						'classic' => esc_html__( 'Classic', 'bestbug' ),
						'advanced_1' => esc_html__( 'Advanced 1', 'bestbug' ),
						'advanced_2' => esc_html__( 'Advanced 2', 'bestbug' ),
						'advanced_3' => esc_html__( 'Advanced 3', 'bestbug' ),
						'advanced_4' => esc_html__( 'Advanced 4', 'bestbug' ),
						'gradient' => esc_html__( 'Gradient', 'bestbug' ),
						'magic' => esc_html__( 'Magic', 'bestbug' ),
						'minisize' => esc_html__( 'Minisize', 'bestbug' ),
						'multiple_blocks' => esc_html__( 'Multiple blocks', 'bestbug' ),
					),
					'param_name'  => $prefix . 'box_style',
					'std' => 'classic',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'box' ) ),
				),
				
				array(
					'type'        => 'dropdown',
					'heading'    => esc_html__( 'Columns', 'bestbug' ),
					'value'       => array(
						'1' => esc_html__( '1 Column', 'bestbug' ),
						'2' => esc_html__( '2 Columns', 'bestbug' ),
						'3' => esc_html__( '3 Columns', 'bestbug' ),
						'4' => esc_html__( '4 Columns', 'bestbug' ),
						'5' => esc_html__( '5 Columns', 'bestbug' ),
						'6' => esc_html__( '6 Columns', 'bestbug' ),
					),
					'param_name'  => $prefix . 'columns',
					'std' => 'classic',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'box' ) ),
				),
				array(
					'type'       => 'toggle',
					'heading'    => esc_html__( 'Border', 'bestbug' ),
					'param_name' => $prefix . 'box_border',
					'value'      => 'no',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'box' ) ),
				),
				array(
					'type'       => 'toggle',
					'heading'    => esc_html__( 'Shadow', 'bestbug' ),
					'param_name' => $prefix . 'box_shadow',
					'value'      => 'yes',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'box' ) ),
				),
			);
			$spark_charts = array(
				array(
					'type'        => 'dropdown',
					'heading'    => esc_html__( 'Style', 'bestbug' ),
					'value'       => array(
						'advanced_3' => esc_html__( 'Classic', 'bestbug' ),
						'advanced_1' => esc_html__( 'Advanced 1', 'bestbug' ),
						'advanced_2' => esc_html__( 'Advanced 2', 'bestbug' ),
						'classic' => esc_html__( 'Advanced 3', 'bestbug' ),
						'advanced_4' => esc_html__( 'Advanced 4', 'bestbug' ),
					),
					'param_name'  => $prefix . 'sparkchart_style',
					'std' => 'classic',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'spark-charts' ) ),
				),
				array(
					'type'       => 'toggle',
					'heading'    => esc_html__( 'Border', 'bestbug' ),
					'param_name' => $prefix . 'sparkchart_border',
					'value'      => 'no',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'spark-charts' ) ),
				),
				array(
					'type'       => 'toggle',
					'heading'    => esc_html__( 'Shadow', 'bestbug' ),
					'param_name' => $prefix . 'sparkchart_shadow',
					'value'      => 'yes',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'spark-charts' ) ),
				),
			);
			$leaderboard = array(
				array(
					'type'        => 'dropdown',
					'heading'    => esc_html__( 'Style', 'bestbug' ),
					'value'       => array(
						'advanced_2' => esc_html__( 'Classic', 'bestbug' ),
						'advanced_1' => esc_html__( 'Advanced', 'bestbug' ),
					),
					'param_name'  => $prefix . 'leaderboard_style',
					'std' => 'classic',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'leaderboard' ) ),
				),
				array(
					'type'       => 'toggle',
					'heading'    => esc_html__( 'Border', 'bestbug' ),
					'param_name' => $prefix . 'leaderboard_border',
					'value'      => 'no',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'leaderboard' ) ),
				),
				array(
					'type'       => 'toggle',
					'heading'    => esc_html__( 'Shadow', 'bestbug' ),
					'param_name' => $prefix . 'leaderboard_shadow',
					'value'      => 'yes',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'leaderboard' ) ),
				),
			);
			$table = array(
				// array(
				// 	'type'        => 'checkbox',
				// 	'heading'     => esc_html__( 'Show Fields', 'bestbug' ),
				// 	'value'       => array(
				// 		'rank' => esc_html__( 'Rank', 'bestbug' ),
				// 		'name' => esc_html__( 'Name', 'bestbug' ),
				// 		'price' => esc_html__( 'Price', 'bestbug' ),
				// 		'supply' => esc_html__( 'Supply', 'bestbug' ),
				// 		'volume' => esc_html__( 'Volume', 'bestbug' ),
				// 		'market_cap' => esc_html__( 'Market Cap', 'bestbug' ),
				// 		'change24h' => esc_html__( 'Change 24h', 'bestbug' ),
				// 		'chart_change24h' => esc_html__( 'Chart change 24h', 'bestbug' ),
				// 	),
				// 	'param_name'  => $prefix . 'table_fields',
				// 	'std' => array(
				// 		'rank' => 1,
				// 		'name' => 1,
				// 		'price' => 1,
				// 		'supply' => 1,
				// 		'volume' => 1,
				// 		'market_cap' => 1,
				// 		'change24h' => 1,
				// 		'chart_change24h' => 1,
				// 	),
				// 	'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'table' ) ),
				// 	'description' => esc_html__( 'Choose the fields to show.', 'bestbug' ),
				// ),
				array(
					'type'       => 'toggle',
					'heading'    => esc_html__( 'Ordering', 'bestbug' ),
					'param_name' => $prefix . 'ordering',
					'value'      => 'yes',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'table' ) ),
				),
				// array(
				// 	'type'       => 'toggle',
				// 	'heading'    => esc_html__( 'Info', 'bestbug' ),
				// 	'param_name' => $prefix . 'info',
				// 	'value'      => 'no',
				// 	'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'table' ) ),
				// ),
				array(
					'type'       => 'toggle',
					'heading'    => esc_html__( 'Searching', 'bestbug' ),
					'param_name' => $prefix . 'searching',
					'value'      => 'no',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'table' ) ),
				),
				// array(
				// 	'type'       => 'toggle',
				// 	'heading'    => esc_html__( 'Display all coins', 'bestbug' ),
				// 	'param_name' => $prefix . 'all_coins',
				// 	'value'      => 'no',
				// 	'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'table' ) ),
				// ),
				// array(
				// 	'type'       => 'toggle',
				// 	'heading'    => esc_html__( 'Paging', 'bestbug' ),
				// 	'param_name' => $prefix . 'paging',
				// 	'value'      => 'no',
				// 	'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'table' ) ),
				// ),
				array(
					'type'        => 'dropdown',
					'heading'    => esc_html__( 'Number of coins per page', 'bestbug' ),
					'value'       => array(
						'10' => esc_html__( '10 coins', 'bestbug' ),
						'20' => esc_html__( '20 coins', 'bestbug' ),
						'25' => esc_html__( '25 coins', 'bestbug' ),
						'50' => esc_html__( '50 coins', 'bestbug' ),
						'75' => esc_html__( '75 coins', 'bestbug' ),
						'100' => esc_html__( '100 coins', 'bestbug' ),
						// '-1' => esc_html__( 'All coins', 'bestbug' ),
					),
					'param_name'  => $prefix .'pageLength',
					'std' => '10',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'table' ) ),
				),
				array(
					'type'        => 'dropdown',
					'heading'    => esc_html__( 'Size', 'bestbug' ),
					'value'       => array(
						'small' => esc_html__( 'Small', 'bestbug' ),
						'medium' => esc_html__( 'Medium', 'bestbug' ),
						'large' => esc_html__( 'Large', 'bestbug' ),
					),
					'param_name'  => $prefix . 'size',
					'std' => 'medium',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'table' ) ),
				),
				array(
					'type'       => 'toggle',
					'heading'    => esc_html__( 'Has Border', 'bestbug' ),
					'param_name' => $prefix . 'hasBorder',
					'value'      => 'yes',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'table' ) ),
				),
				array(
					'type'       => 'toggle',
					'heading'    => esc_html__( 'Hight Light Realtime', 'bestbug' ),
					'param_name' => $prefix . 'highLightRealtime',
					'value'      => 'yes',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'table' ) ),
				),
				array(
					'type'       => 'toggle',
					'heading'    => esc_html__( 'Hight Light Even Row', 'bestbug' ),
					'param_name' => $prefix . 'hightLightEvenRow',
					'value'      => 'yes',
					'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'table' ) ),
				),
				
				// array(
				// 	'type'        => 'checkbox',
				// 	'heading'     => esc_html__( 'Show columns', 'bestbug' ),
				// 	'value'       => array(
				// 		'mktcap' => esc_html__( 'Market Cap', 'bestbug' ),
				// 		'price' => esc_html__( 'Price', 'bestbug' ),
				// 		'vwapData' => esc_html__( '24hour VWAP', 'bestbug' ),
				// 		'supply' => esc_html__( 'Available Supply', 'bestbug' ),
				// 		'volume' => esc_html__( '24 Hour Volume', 'bestbug' ),
				// 		'cap24hrChange' => esc_html__( '%24hr', 'bestbug' ),
				// 	),
				// 	'param_name'  => $prefix . 'show_columns',
				// 	'std' => array(
				// 		'mktcap' => 1,
				// 		'price' => 1,
				// 		'vwapData' => 1,
				// 		'supply' => 1,
				// 		'volume' => 1,
				// 		'cap24hrChange' => 1,
				// 	),
				// 	'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'table', 'comparison' ) ),
				// 	'description' => esc_html__( 'Choose the columns to show.', 'bestbug' ),
				// ),
			);
			
			$ticker = array(
				array(
					'type'       => 'toggle',
					'heading'    => esc_html__( 'Has Background', 'bestbug' ),
					'param_name' => $prefix . 'has_background',
					'value'      => 'yes',
					'dependency'  => array( 
						'element' => $prefix . 'layout',
						'value' => array( 'ticker' ) 
					),
				),
				// array(
				// 	'type'        => 'dropdown',
				// 	'heading'    => esc_html__( 'Display', 'bestbug' ),
				// 	'value'       => array(
				// 		'inline' => esc_html__( 'Inline', 'bestbug' ),
				// 		'top-fixed' => esc_html__( 'Top Fixed', 'bestbug' ),
				// 		'bottom-fixed' => esc_html__( 'Bottom Fixed', 'bestbug' ),
				// 	),
				// 	'param_name' => $prefix . 'ticker_display',
				// 	'std' => 'inline',
				// 	'dependency'  => array( 'element' => $prefix . 'layout', 'value' => array( 'ticker' ) ),
				// ),
			);
			
			$options[] = array(
				'type' => 'post_fields',
				'ajax_action' => 'bb_save_post',
				'menu' => array(
					// add_submenu_page || add_menu_page
					'type' => 'add_submenu_page',
					'parent_slug' => BESTBUG_CRYPTO_SLUG,
					'page_title' => esc_html('Ultimate Crypto Widgets shortcode', 'bestbug'),
					'menu_title' => esc_html('Add shortcode', 'bestbug'),
					'capability' => 'manage_options',
					'menu_slug' => BESTBUG_CRYPTO_ADD_REALCRYPTO_SLUG,
				),
				'fields' => array_merge($general, $box, $spark_charts, $leaderboard, $table, $inline),
				'fields' => array_merge(
					$general, 
					$box, 
					$spark_charts, 
					$table, 
					$inline, 
					$ticker,
					$leaderboard
				),
			);
			
			return $options;
        }
        
    }
	
	new BESTBUG_CRYPTO_REALCRYPTO();
}

