<?php
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! class_exists( 'BESTBUG_CRYPTO_AJAX' ) ) {
	/**
	 * BESTBUG_CRYPTO_AJAX Class
	 *
	 * @since	1.0
	 */
	class BESTBUG_CRYPTO_AJAX {


		/**
		 * Constructor
		 *
		 * @return	void
		 * @since	1.0
		 */
		function __construct() {
			$this->init();
		}

		public function init() {
			
			add_action( 'wp_ajax_' . BESTBUG_CRYPTO_AJAX_EXCHANGE_RATES, array( $this, 'bbcrypto_exchange_rates') );
			add_action( 'wp_ajax_nopriv_' . BESTBUG_CRYPTO_AJAX_EXCHANGE_RATES, array( $this, 'bbcrypto_exchange_rates') );
			
			add_action( 'wp_ajax_ucw_history24h', array( $this, 'getHistory24h') );
			add_action( 'wp_ajax_nopriv_ucw_history24h', array( $this, 'getHistory24h') );
			
			add_action( 'wp_ajax_ucw_getcoins', array( $this, 'getCoinsData') );
			add_action( 'wp_ajax_nopriv_ucw_getcoins', array( $this, 'getCoinsData') );
			
        }
        
		public function bbcrypto_exchange_rates() {
			header('Content-Type: application/json');
			$body=file_get_contents('https://api.fixer.io/latest?base=USD');
			echo $body;
			exit;
		}
		
		public function getCoinsData(){
			$coins = $_POST['coins'];
			$data = json_decode(file_get_contents('https://min-api.cryptocompare.com/data/pricemultifull?fsyms='.$coins.'&tsyms=USD'));
			
			if(isset($data->RAW)) {
				$coinsData = array();
				foreach ($data->RAW as $key => $coin) {
					$coin = $coin->USD;
					$coinsData[$key] = array(
						'price' => $coin->PRICE,
						'lastMarket' => $coin->LASTMARKET,
						'low24h' => $coin->LOW24HOUR,
						'high24h' => $coin->HIGH24HOUR,
						'change24h' => $coin->CHANGE24HOUR,
						'changePct24h' => $coin->CHANGEPCT24HOUR,
						'open24h' => $coin->OPEN24HOUR,
						'mktCap' => $coin->MKTCAP,
						'supply' => $coin->SUPPLY,
						'volumne24h' => $coin->VOLUME24HOUR,
						'volumne24hTo' => $coin->VOLUME24HOURTO,
						'totalVolume24h' => $coin->TOTALVOLUME24HTO,
					);
				}
				echo json_encode(
					array(
						'status' => 'ok',
						'coins' => $coinsData,
					)
				);
				exit;
			}
			echo json_encode(
				array(
					'status' => 'error',
					'data' => json_decode($data)
				)
			);
			exit;
		}
		
		public function getHistory24h(){
			$coin = $_POST['coin'];
			$time = time();
			$chart24h = get_option(BESTBUG_CRYPTO_PREFIX . 'chart24h');
			
			if(isset($chart24h[$coin]['time']) && $time - $chart24h[$coin]['time'] < 60 * 60 ) {
				echo '['.implode(',', $chart24h[$coin]['chart24h']).']';
				exit;
			}
			
			if(!is_array($chart24h)) {
				$chart24h = array();
			}
			$data = json_decode(file_get_contents('https://min-api.cryptocompare.com/data/histohour?fsym='.$coin.'&tsym=USD&limit=23&aggregate=3&e=CCCAGG'));
			if(isset($data->Data)) {
				$chart24h[$coin]['chart24h'] = array();
				foreach ($data->Data as $key => $data) {
					$chart24h[$coin]['chart24h'][] = $data->close;
					//array_push(, $data->close);
				}
				$chart24h[$coin]['time'] = time();
			} else {
				$chart24h[$coin]['chart24h'][] = 0;
			}
			
			// $data24h = json_decode(file_get_contents('http://coincap.io/history/1day/'.$coin));
			// if(isset($data24h->price)) {
			// 	foreach ($data24h->price as $key => $data) {
			// 		array_push($chart24h, $data[1]);
			// 	}
			// } else {
			// 	$chart24h[] = 1;
			// }
			// var_dump($chart24h); die;
			BESTBUG_HELPER::update_option(BESTBUG_CRYPTO_PREFIX . 'chart24h', $chart24h);
			
			echo '['.implode(',', $chart24h[$coin]['chart24h']).']';
			exit;
		}
		
	}
	
	new BESTBUG_CRYPTO_AJAX();
}

