<?php
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! class_exists( 'BESTBUG_CRYPTO_SHORTCODE' ) ) {
	/**
	 * BESTBUG_CRYPTO_SHORTCODE Class
	 *
	 * @since	1.0
	 */
	class BESTBUG_CRYPTO_SHORTCODE {

		/**
		 * Constructor
		 *
		 * @return	void
		 * @since	1.0
		 */
		function __construct() {
			
			add_shortcode( BESTBUG_CRYPTO_SHORTCODE, array( $this, 'shortcode' ) );
			add_shortcode( 'cryptocompare', array( $this, 'shortcode' ) );
			add_shortcode( BESTBUG_CRYPTOCOMPARE_SHORTCODE, array( $this, 'shortcode' ) );

			if(is_admin()) {
				add_action( 'admin_enqueue_scripts', array( $this, 'adminEnqueueScripts' ) );
			}
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueueScripts' ) );
			add_action( 'init', array( $this, 'init' ) );
		}

		public function init() {
			if ( defined( 'WPB_VC_VERSION' ) && function_exists( 'vc_add_param' ) ) {
				$this->vc_shortcode();
			}
        }

		public function adminEnqueueScripts() {
			// wp_enqueue_style( 'css', BESTBUG_CRYPTO_URL . '/assets/admin/css/style.css' );
			// wp_enqueue_script( 'js', BESTBUG_CRYPTO_URL . '/assets/admin/js/script.js', array( 'jquery' ), '1.0', true );
		}

		public function enqueueScripts() {
			// wp_enqueue_style( 'css', BESTBUG_CRYPTO_URL . '/assets/css/style.css' );
			// wp_enqueue_script( 'js', BESTBUG_CRYPTO_URL . '/assets/js/script.js', array( 'jquery' ), '1.0', true );
		}
        
        public function vc_shortcode() {
			
			$shortcodes = get_posts(array(
				'numberposts' => -1,
				'post_type' => BESTBUG_CRYPTO_POSTTYPE,
				'orderby' => 'title',
				'order'   => 'ASC',
			));
			$values = array();
			if(is_array($shortcodes)) {
				foreach ($shortcodes as $id => $shortcode) {
					$values[$shortcode->post_title . ' '] = $shortcode->ID;
				}
			}
			
			vc_map( array(
			    "name" => esc_html__( "Ultimate Crypto Widgets", 'bestbug' ),
			    "base" => BESTBUG_CRYPTOCOMPARE_SHORTCODE,
			    "content_element" => true,
				"icon" => "icon-" . BESTBUG_CRYPTOCOMPARE_SHORTCODE,
				"description" => esc_html__( "Display Ultimate Crypto Widgets Shortcode", 'bestbug' ),
				'category' => esc_html( sprintf( esc_html__( 'by %s', 'bestbug' ), BESTBUG_CRYPTO_CATEGORY ) ),
			    "params" => array(
					array(
				        'type'        => 'dropdown',
				        'heading'     => esc_html__( 'Choose Ultimate Crypto Widgets Shortcode', 'bestbug' ),
				        'value'       => $values,
				        'param_name'  => 'id',
						'admin_label' => true,
						'save_always' => true,
			        ),
			    ),
			) );
        }
		
		public function shortcode( $atts, $content = null ) {
			shortcode_atts( array(
				'id' => '',
				'css' => '',
				'el_class' => '',
			), $atts );
			
			$shortcode = get_post( $atts['id'] ); 
			
			if(!$shortcode || !isset($shortcode->ID)) {
				return esc_html__('Not found the shortcode!', 'bestbug');
			}
			
			$layout = get_post_meta($shortcode->ID, BESTBUG_CRYPTO_PREFIX . 'layout', true);
			$attsData = '';
			
			switch ($layout) {
				case 'table':
					$keys = array(
						'only_coins',
						
						// table option
						"paging",
						'pageLength',
				        "ordering",
				        "info",
						'searching',
						// style
						'size', // small, medium, large
						'hasBorder',
						'highLightRealtime',
						'hightLightEvenRow',
						'skin',
						'high_light',
						'detail_url',
					);
					foreach ($keys as $index => $key) {
						$value = get_post_meta($shortcode->ID, BESTBUG_CRYPTO_PREFIX . $key, true);
						if($key == 'table_fields') {
							if(empty($value)) {
								$value = array(
									'rank' => 1,
									'name' => 1,
									'price' => 1,
									'supply' => 1,
									'volume' => 1,
									'market_cap' => 1,
									'change24h' => 1,
									'chart_change24h' => 1
								);
							}
							foreach ($value as $field => $use) {
								if($use != 1) {
									unset($value[$field]);
								}
							}
							$attsData .= $key . '="'.implode(',', array_keys($value)).'" ';
						} else if(is_array($value)) {
							$attsData .= $key . '="'.implode(',', $value).'" ';
						} else {
							$attsData .= $key . '="'.$value.'" ';
						}
					}
					return do_shortcode('['.BESTBUG_CRYPTO_TABLE_SHORTCODE.' '.$attsData.' ]');
					break;
				case 'ticker':
					$keys = array(
						'only_coins',
						'inline_fields',
						'high_light',
						'skin',
						'has_background',
					);
					foreach ($keys as $index => $key) {
						if($key == 'only_coins' && isset($_GET[BESTBUG_CRYPTO_QUERYVAR]) && !empty($_GET[BESTBUG_CRYPTO_QUERYVAR])) {
							$attsData .= $key . '="'.$_GET[BESTBUG_CRYPTO_QUERYVAR].'" ';
							continue;
						}
						$value = get_post_meta($shortcode->ID, BESTBUG_CRYPTO_PREFIX . $key, true);
						if($key == 'inline_fields') {
							foreach ($value as $field => $use) {
								if($use != 1) {
									unset($value[$field]);
								}
							}
							$attsData .= $key . '="'.implode(',', array_keys($value)).'" ';
						} else if(is_array($value)) {
							$attsData .= $key . '="'.implode(',', $value).'" ';
						} else {
							$attsData .= $key . '="'.$value.'" ';
						}
					}
					return do_shortcode('['.BESTBUG_CRYPTO_TICKER_SHORTCODE.' '.$attsData.' ]');
					break;
				case 'inline':
					$keys = array(
						'only_coins',
						'inline_fields',
						'high_light',
						'skin',
					);
					foreach ($keys as $index => $key) {
						if($key == 'only_coins' && isset($_GET[BESTBUG_CRYPTO_QUERYVAR]) && !empty($_GET[BESTBUG_CRYPTO_QUERYVAR])) {
							$attsData .= $key . '="'.$_GET[BESTBUG_CRYPTO_QUERYVAR].'" ';
							continue;
						}
						$value = get_post_meta($shortcode->ID, BESTBUG_CRYPTO_PREFIX . $key, true);
						if($key == 'inline_fields') {
							foreach ($value as $field => $use) {
								if($use != 1) {
									unset($value[$field]);
								}
							}
							$attsData .= $key . '="'.implode(',', array_keys($value)).'" ';
						} else if(is_array($value)) {
							$attsData .= $key . '="'.implode(',', $value).'" ';
						} else {
							$attsData .= $key . '="'.$value.'" ';
						}
					}
					return do_shortcode('['.BESTBUG_CRYPTO_INLINE_SHORTCODE.' '.$attsData.' ]');
					break;
				case 'leaderboard':

					$keys = array(
						'only_coins',
						'shape',
						'leaderboard_style',
						'skin',
						'high_light',
						'leaderboard_border',
						'leaderboard_shadow',
					);
					foreach ($keys as $index => $key) {
						if($key == 'only_coins' && isset($_GET[BESTBUG_CRYPTO_QUERYVAR]) && !empty($_GET[BESTBUG_CRYPTO_QUERYVAR])) {
							$attsData .= $key . '="'.$_GET[BESTBUG_CRYPTO_QUERYVAR].'" ';
							continue;
						}
						$value = get_post_meta($shortcode->ID, BESTBUG_CRYPTO_PREFIX . $key, true);
						if(is_array($value)) {
							$attsData .= $key . '="'.implode(',', $value).'" ';
						} else {
							$attsData .= $key . '="'.$value.'" ';
						}
					}
					
					return do_shortcode('['.BESTBUG_CRYPTO_LEADERBOARD_SHORTCODE.' '.$attsData.' ]');
					break;
				case 'spark-charts':

					$keys = array(
						'only_coins',
						'shape',
						'sparkchart_style',
						'skin',
						'high_light',
						'sparkchart_border',
						'sparkchart_shadow',
					);
					foreach ($keys as $index => $key) {
						if($key == 'only_coins' && isset($_GET[BESTBUG_CRYPTO_QUERYVAR]) && !empty($_GET[BESTBUG_CRYPTO_QUERYVAR])) {
							$attsData .= $key . '="'.$_GET[BESTBUG_CRYPTO_QUERYVAR].'" ';
							continue;
						}
						$value = get_post_meta($shortcode->ID, BESTBUG_CRYPTO_PREFIX . $key, true);
						if(is_array($value)) {
							$attsData .= $key . '="'.implode(',', $value).'" ';
						} else {
							$attsData .= $key . '="'.$value.'" ';
						}
					}
					return do_shortcode('['.BESTBUG_CRYPTO_SPARKCHARTS_SHORTCODE.' '.$attsData.' ]');
					break;
				case 'comparison':
					$keys = array(
						'only_coins',
						'high_light',
						'highLightRealtime',
						'skin',
					);
					foreach ($keys as $index => $key) {
						if($key == 'only_coins' && isset($_GET[BESTBUG_CRYPTO_QUERYVAR]) && !empty($_GET[BESTBUG_CRYPTO_QUERYVAR])) {
							$attsData .= $key . '="'.$_GET[BESTBUG_CRYPTO_QUERYVAR].'" ';
							continue;
						}
						$value = get_post_meta($shortcode->ID, BESTBUG_CRYPTO_PREFIX . $key, true);
						if($key == 'inline_fields') {
							foreach ($value as $field => $use) {
								if($use != 1) {
									unset($value[$field]);
								}
							}
							$attsData .= $key . '="'.implode(',', array_keys($value)).'" ';
						} else if(is_array($value)) {
							$attsData .= $key . '="'.implode(',', $value).'" ';
						} else {
							$attsData .= $key . '="'.$value.'" ';
						}
					}
					
					return do_shortcode('['.BESTBUG_CRYPTO_COMPARISON_SHORTCODE.' '.$attsData.' ]');
					break;
				case 'chart':
					$keys = array(
						'only_coins',
						'high_light',
						'skin',
					);
					foreach ($keys as $index => $key) {
						if($key == 'only_coins' && isset($_GET[BESTBUG_CRYPTO_QUERYVAR]) && !empty($_GET[BESTBUG_CRYPTO_QUERYVAR])) {
							$attsData .= $key . '="'.$_GET[BESTBUG_CRYPTO_QUERYVAR].'" ';
							continue;
						}
						$value = get_post_meta($shortcode->ID, BESTBUG_CRYPTO_PREFIX . $key, true);
						if(is_array($value)) {
							$attsData .= $key . '="'.implode(',', $value).'" ';
						} else {
							$attsData .= $key . '="'.$value.'" ';
						}
					}
					
					return do_shortcode('['.BESTBUG_CRYPTO_CHART_SHORTCODE.' '.$attsData.' ]');
					break;
				case 'box':
					$keys = array(
						'only_coins',
						'shape',
						'box_style',
						'skin',
						'high_light',
						'columns',
						'box_border',
						'fill_background',
						'box_shadow',
					);
					foreach ($keys as $index => $key) {
						if($key == 'only_coins' && isset($_GET[BESTBUG_CRYPTO_QUERYVAR]) && !empty($_GET[BESTBUG_CRYPTO_QUERYVAR])) {
							$attsData .= $key . '="'.$_GET[BESTBUG_CRYPTO_QUERYVAR].'" ';
							continue;
						}
						$value = get_post_meta($shortcode->ID, BESTBUG_CRYPTO_PREFIX . $key, true);
						if(is_array($value)) {
							$attsData .= $key . '="'.implode(',', $value).'" ';
						} else {
							$attsData .= $key . '="'.$value.'" ';
						}
					}
					return do_shortcode('['.BESTBUG_CRYPTO_BOX_SHORTCODE.' '.$attsData.' ]');
					break;
				case 'convert':
					$keys = array(
						'shape',
						'skin',
					);
					foreach ($keys as $index => $key) {
						$value = get_post_meta($shortcode->ID, BESTBUG_CRYPTO_PREFIX . $key, true);
						if(is_array($value)) {
							$attsData .= $key . '="'.implode(',', $value).'" ';
						} else {
							$attsData .= $key . '="'.$value.'" ';
						}
					}
					return do_shortcode('['.BESTBUG_CRYPTO_CONVERT_SHORTCODE.' '.$attsData.' ]');
					break;
				default:
					return esc_html__('Not found the shortcode!', 'bestbug');
					break;
			}
			
			return;
		}
        
    }
	
	new BESTBUG_CRYPTO_SHORTCODE();
}

