<?php
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! class_exists( 'BESTBUG_CRYPTO_BOX_SHORTCODE' ) ) {
	/**
	 * BESTBUG_CRYPTO_BOX_SHORTCODE Class
	 *
	 * @since	1.0
	 */
	class BESTBUG_CRYPTO_BOX_SHORTCODE {

		/**
		 * Constructor
		 *
		 * @return	void
		 * @since	1.0
		 */
		function __construct() {
			$this->init();
		}

		public function init() {
			
			add_shortcode( BESTBUG_CRYPTO_BOX_SHORTCODE, array( $this, 'shortcode' ) );
			if ( defined( 'WPB_VC_VERSION' ) && function_exists( 'vc_add_param' ) ) {
				$this->vc_shortcode();
			}

			if(is_admin()) {
				add_action( 'admin_enqueue_scripts', array( $this, 'adminEnqueueScripts' ) );
			}
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueueScripts' ) );

        }

		public function adminEnqueueScripts() {
		}

		public function enqueueScripts() {
		}
        
        public function vc_shortcode() {
			
        }
		
		public function shortcode( $atts, $content = null ) {
			shortcode_atts( array(
				'all_coins' => '',
				'only_coins' => '',
				'box_style' => '',
				'columns' => '',
				'skin' => '',
				'shape' => '',
				'high_light' => '',
				'box_border' => '',
				'box_shadow' => '',
				'fill_background' => '',
			), $atts );
			
			$table_atts = ''; $dataCoins = '<tbody>';
			$container_class = array(
				'realcrypto',
				'realcrypto-box-wrap',
			);
			
			if(isset($atts['skin']) && !empty($atts['skin'])) {
				$container_class[] = 'rc-color-'.$atts['skin'];
			}
			if(isset($atts['box_style']) && !empty($atts['box_style'])) {
				$container_class[] = 'rc-boxstyle-'.$atts['box_style'];
			}
			if(isset($atts['shape']) && !empty($atts['shape'])) {
				$container_class[] = 'rc-boxshape-'.$atts['shape'];
			}
			if(isset($atts['columns']) && !empty($atts['columns'])) {
				$container_class[] = 'rc-columns-'.$atts['columns'];
			}
			if(isset($atts['high_light']) && $atts['high_light'] == 'yes') {
				$container_class[] = 'rc-highlight';
			}
			if(isset($atts['box_shadow']) && $atts['box_shadow'] == 'yes') {
				$container_class[] = 'rc-box-shadow';
			}
			if(isset($atts['box_border']) && $atts['box_border'] == 'yes') {
				$container_class[] = 'rc-box-border';
			}
			if(isset($atts['fill_background']) && $atts['fill_background'] == 'yes') {
				$container_class[] = 'rc-fill-bg';
			}
			
			$only_coins = explode(',', $atts['only_coins']);
			if(is_array($only_coins) && count($only_coins) > 0) {
				foreach ($only_coins as $key => $coins) {
					if(array_key_exists( $coins, BESTBUG_CRYPTO_HELPER::$alias)) {
						$coins = BESTBUG_CRYPTO_HELPER::$alias[$coins];
					}
					if($atts['box_style'] == 'classic'):
						$dataCoins .= '<div class="realcrypto-box-single-wrap" data-coin="'.$coins.'">
						<div class="realcrypto-box-single">
							<div class="rc-pos-top">
								<div class="rc-sub-left">
									<div class="rc-name-wrap">
										<span class="rc-coinname-'.$coins.'"></span>
										<strong>
											<span class="rc-name-'.$coins.'"></span>
										</strong>
									</div>
									<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-up-color rc-arrow-up dashicons dashicons-arrow-up-alt"></span>
									<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-down-color rc-arrow-down dashicons dashicons-arrow-down-alt"></span>
									
									<span class="rc-PRICE-'.$coins.'"></span> 
								</div>
								<div class="rc-sub-right">
									<span class="rc-image-" data-coin-image="'.strtoupper(str_replace("*","_",$coins)).'"></span>
								</div>
							</div>
							<div class="rc-pos-bottom">
								<div class="rc-sub-right">
									<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-CHANGE24HOUR-'.$coins.'"></span>  
									(<span class="rc-wrap-CHANGE24HOURPCT-'.$coins.' rc-CHANGE24HOURPCT-'.$coins.'"></span>)
								</div>
							</div>
						</div>
						</div>';
					elseif($atts['box_style'] == 'gradient'):
						$dataCoins .= '<div class="realcrypto-box-single-wrap" data-coin="'.$coins.'">
						<div class="realcrypto-box-single">
							<div class="rc-pos-top">
								<div class="rc-price-label">'.esc_html__('PRICE', 'bestbug').'</div>
								<div class="rc-PRICE-'.$coins.'"></div>
							</div>
							<div class="rc-ic-coin">
				                <span class="rc-image-" data-coin-image="'.strtoupper(str_replace("*","_",$coins)).'"></span>
				            </div>
				            <div class="rc-info">
				                <div class="rc-info-sub">
			                		<span class="rc-coinname-'.$coins.'"></span>
			                		(<span class="rc-name-'.$coins.'"></span>)
			                	</div>
			                	<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-up-color rc-arrow-up dashicons dashicons-arrow-up-alt"></span>
								<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-down-color rc-arrow-down dashicons dashicons-arrow-down-alt"></span>
			                    <span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-CHANGE24HOUR-'.$coins.'"></span>  
								(<span class="rc-wrap-CHANGE24HOURPCT-'.$coins.' rc-CHANGE24HOURPCT-'.$coins.'"></span>)
				            </div>
						</div>
						</div>';
					elseif($atts['box_style'] == 'magic'):
						$dataCoins .= '<div class="realcrypto-box-single-wrap" data-coin="'.$coins.'">
						<div class="realcrypto-box-single">
							<div class="rc-pos-top">
								<div class="rc-param">
									<div class="rc-lbl-01">'.esc_html__('PRICE', 'bestbug').'</div>
									<div class="rc-PRICE-'.$coins.'"></div>
								</div>
							</div>
							<div class="rc-pos-bottom">
								<div class="rc-ic-coin">
									<span class="rc-image-'.$coins.'"></span>
								</div>
								<div class="rc-name-wrap">
									<span class="rc-coinname-'.$coins.'"></span>
									(<span class="rc-name-'.$coins.'"></span>)
								</div>
								<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-up-color rc-arrow-up dashicons dashicons-arrow-up-alt"></span>
								<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-down-color rc-arrow-down dashicons dashicons-arrow-down-alt"></span>
								<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-CHANGE24HOUR-'.$coins.'"></span>  
								(<span class="rc-wrap-CHANGE24HOURPCT-'.$coins.' rc-CHANGE24HOURPCT-'.$coins.'"></span>)
							</div>
						</div>
						</div>';
					elseif($atts['box_style'] == 'minisize'):
						$dataCoins .= '<div class="realcrypto-box-single-wrap" data-coin="'.$coins.'">
						<div class="realcrypto-box-single">
				            <div class="rc-ic-coin">
				                <span class="rc-image-'.$coins.'"></span> 
				            </div>
				            <div class="rc-info">
				                <span class="rc-name-'.$coins.'"></span> 
			                	<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-up-color rc-arrow-up dashicons dashicons-arrow-up-alt"></span> 
								<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-down-color rc-arrow-down dashicons dashicons-arrow-down-alt"></span> 
			                    <span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-CHANGE24HOUR-'.$coins.'"></span>   
								(<span class="rc-wrap-CHANGE24HOURPCT-'.$coins.' rc-CHANGE24HOURPCT-'.$coins.'"></span>)
				            </div>
				        </div>
				        </div>';
					elseif($atts['box_style'] == 'multiple_blocks'):
						$dataCoins .= '<div class="realcrypto-box-single-wrap" data-coin="'.$coins.'">
						<div class="realcrypto-box-single">
			                <div class="rc-col-5 rc-left-box">
			                	<div class="rc-coinname-'.$coins.'"></div>
			                    <div class="rc-ic-coin">
					                <span class="rc-image-'.$coins.'"></span>
					                <div class="rc-name-'.$coins.'"></div>
					            </div>
			                </div>
			                <div class="rc-col-7 rc-right-box">
			                    <div class="rc-right-elm">
			                        <span>
			                            <b>
			                            	<span class="rc-PRICE-'.$coins.'"></span>
			                            	<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-up-color rc-arrow-up dashicons dashicons-arrow-up-alt"></span>
											<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-down-color rc-arrow-down dashicons dashicons-arrow-down-alt"></span>
			                            </b>
			                        </span>
			                    </div>
			                    <div class="rc-right-elm">
									<p>
										<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-CHANGE24HOUR-'.$coins.'"></span>  
										(<span class="rc-wrap-CHANGE24HOURPCT-'.$coins.' rc-CHANGE24HOURPCT-'.$coins.'"></span>)
									</p>
			                    </div>
			                </div>
			            </div>
				        </div>';
					elseif($atts['box_style'] == 'advanced_1'):
						$dataCoins .= '<div class="realcrypto-box-single-wrap" data-coin="'.$coins.'">
						<div class="realcrypto-box-single">
			                <div class="rc-ic-coin">
					            <span class="rc-image-'.$coins.'"></span>
			                </div>
			                <div class="rc-info">
			                	<div class="rc-info-top">
			                		<span class="rc-coinname-'.$coins.'"></span>
			                		(<span class="rc-name-'.$coins.'"></span>)
			                	</div>
			                    <span class="rc-param">
			                        <b><span class="rc-PRICE-'.$coins.'"></span></b>
			                        <span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-up-color rc-arrow-up dashicons dashicons-arrow-up-alt"></span>
									<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-down-color rc-arrow-down dashicons dashicons-arrow-down-alt"></span>
			                        <span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-CHANGE24HOUR-'.$coins.'"></span>  
									(<span class="rc-wrap-CHANGE24HOURPCT-'.$coins.' rc-CHANGE24HOURPCT-'.$coins.'"></span>)
			                    </span>
			                </div>
			                <span class="rc-decor rc-image-'.$coins.'"></span>
			            </div>
						</div>';
					elseif($atts['box_style'] == 'advanced_2'):
						$dataCoins .= '<div class="realcrypto-box-single-wrap" data-coin="'.$coins.'">
						<div class="realcrypto-box-single">
							<div class="rc-ic-coin">
			                    <span class="rc-image-'.$coins.'"></span>
			                </div>
			                <div class="rc-info">
			                	<div>
				                    <div class="rc-info-top">
			                        	<span class="rc-coinname-'.$coins.'"></span> 
			                			(<span class="rc-name-'.$coins.'"></span>)
			                		</div>
				                    <span class="">
				                        <div class="rc-price-wrap"><b class="rc-PRICE-'.$coins.'"></b></div>
				                        <span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-up-color rc-arrow-up dashicons dashicons-arrow-up-alt"></span>
										<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-down-color rc-arrow-down dashicons dashicons-arrow-down-alt"></span>
				                        <span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-CHANGE24HOUR-'.$coins.'"></span>  
										(<span class="rc-wrap-CHANGE24HOURPCT-'.$coins.' rc-CHANGE24HOURPCT-'.$coins.'"></span>)
				                    </span>
				                </div>
			                </div>
						</div>
						</div>';
					elseif($atts['box_style'] == 'advanced_3'):
						$dataCoins .= '<div class="realcrypto-box-single-wrap" data-coin="'.$coins.'">
						<div class="realcrypto-box-single">
							<div class="rc-info">
			                    <div class="">
			                        <p><b class="rc-PRICE-'.$coins.'"></b></p>
			                        <span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-up-color rc-arrow-up dashicons dashicons-arrow-up-alt"></span>
									<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-down-color rc-arrow-down dashicons dashicons-arrow-down-alt"></span>
			                        <span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-CHANGE24HOUR-'.$coins.'"></span>  
									(<span class="rc-wrap-CHANGE24HOURPCT-'.$coins.' rc-CHANGE24HOURPCT-'.$coins.'"></span>)
			                    </div>
			                    <div class="name">
			                         <div class="name-inside">
			                        	<span class="rc-coinname-'.$coins.'"></span> 
			                			(<span class="rc-name-'.$coins.'"></span>)
			                		</div>
			                    </div>    
			                </div>
			                <div class="rc-ic-coin">
			                    <span class="rc-image-'.$coins.'"></span>
			                </div>
						</div>
						</div>';
					elseif($atts['box_style'] == 'advanced_4'):
						$dataCoins .= '<div class="realcrypto-box-single-wrap" data-coin="'.$coins.'">
						<div class="realcrypto-box-single">
							<div class="rc-name-wrap">
								<span class="rc-coinname-'.$coins.'"></span> 
			                	(<span class="rc-name-'.$coins.'"></span>)
			                </div>
			                <div class="rc-ic-coin">
			                    <span class="rc-image-'.$coins.'"></span>
			                </div>
			                <div class="rc-info">
			                    <span class="">
			                        <b class="rc-PRICE-'.$coins.'"></b>
			                        <span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-up-color rc-arrow-up dashicons dashicons-arrow-up-alt"></span>
									<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-down-color rc-arrow-down dashicons dashicons-arrow-down-alt"></span>
			          				<p>
			          					<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-CHANGE24HOUR-'.$coins.'"></span> 
			          					(<span class="rc-wrap-CHANGE24HOURPCT-'.$coins.' rc-CHANGE24HOURPCT-'.$coins.'"></span>)
			          				<p>
			                    </span>
			                </div>
						</div>
						</div>';
					endif;
				}
			}
			
			$dataCoins .= '</tbody>';
			
			return '<div class="'.implode(" ", $container_class).'">
						'.$dataCoins.'
					</div>';
		}
        
    }
	
	new BESTBUG_CRYPTO_BOX_SHORTCODE();
}

