<?php
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! class_exists( 'BESTBUG_CRYPTO_COMPARISON_SHORTCODE' ) ) {
	/**
	 * BESTBUG_CRYPTO_COMPARISON_SHORTCODE Class
	 *
	 * @since	1.0
	 */
	class BESTBUG_CRYPTO_COMPARISON_SHORTCODE {

		/**
		 * Constructor
		 *
		 * @return	void
		 * @since	1.0
		 */
		function __construct() {
			$this->init();
		}

		public function init() {
			
			add_shortcode( BESTBUG_CRYPTO_COMPARISON_SHORTCODE, array( $this, 'shortcode' ) );
			if ( defined( 'WPB_VC_VERSION' ) && function_exists( 'vc_add_param' ) ) {
				$this->vc_shortcode();
			}

			if(is_admin()) {
				add_action( 'admin_enqueue_scripts', array( $this, 'adminEnqueueScripts' ) );
			}
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueueScripts' ) );

        }

		public function adminEnqueueScripts() {
		}

		public function enqueueScripts() {
		}
        
        public function vc_shortcode() {
			
        }
		
		public function shortcode( $atts, $content = null ) {
			shortcode_atts( array(
				'only_coins' => '',
				'high_light' => 'yes',
				'highLightRealtime' => 'yes',
				'skin' => '',
			), $atts );
			
			$table_atts = ''; $dataCoins = '';
			$container_class = array(
				'realcrypto',
				'realcrypto-comparison-wrap',
			);
			
			// Table style
			if(isset($atts['skin'])) {
				$container_class[] = 'rc-color-' . $atts['skin'];
			}
			if(isset($atts[strtolower('highLightRealtime')]) && $atts[strtolower('highLightRealtime')] == 'yes') {
				$container_class[] = 'rc-highLightRealtime';
			}
			if(isset($atts['high_light']) && $atts['high_light'] == 'yes') {
				$container_class[] = 'rc-highlight';
			}
			if(isset($atts[strtolower('hasBorder')]) && $atts[strtolower('hasBorder')] == 'yes') {
				$container_class[] = 'rc-hasBorder';
			}
			
			$only_coins = explode(',', $atts['only_coins']);
			if(is_array($only_coins) && count($only_coins) > 0) {
				foreach ($only_coins as $key => $coins) {
					if(array_key_exists( $coins, BESTBUG_CRYPTO_HELPER::$alias)) {
						$coins = BESTBUG_CRYPTO_HELPER::$alias[$coins];
					}
					$dataCoins .= '<div class="comparison" data-coin="'.$coins.'">
						<div class="top-info">
							<span class="rc-image-'.$coins.'"></span>
							<span class="rc-name-'.$coins.'"></span>
							<span class="rc-highlight rc-wrap-PRICE-'.$coins.' rc-PRICE-'.$coins.'"></span>
						</div> <!-- .top-info -->

						<div class="rc-features-list">
							<div><span class="rc-coinname-'.$coins.'"></span></div>
							<div><span class="rc-OPEN24HOUR-'.$coins.'"></span></div>
							<div><span class="rc-LOW24HOUR-'.$coins.'"></span> </div>
							<div><span class="rc-HIGH24HOUR-'.$coins.'"></span></div>
							<div><span class="rc-CHANGE24HOUR-'.$coins.'"></span></div>
							<div><span class="rc-CHANGE24HOURPCT-'.$coins.'"></span></div>
							<div><span class="rc-VOLUME24HOUR-'.$coins.'"></span></div>
							<div><span class="rc-LASTMARKET-'.$coins.'"></span></div>
						</div>
					</div>';
				}
			}
			
			return '<div class="'.implode(" ", $container_class).'">
			<section class="rc-comparisons-comparison-table">
				<div class="rc-comparisons-table">
					<div class="features">
						<div class="top-info"></div>
						<div class="rc-features-list">
							<div>'.esc_html('Name','bestbug').'</div>
							<div>'.esc_html('Open 24H','bestbug').'</div>
							<div>'.esc_html('Low 24H','bestbug').'</div>
							<div>'.esc_html('High 24H','bestbug').'</div>
							<div>'.esc_html('Change','bestbug').'</div>
							<div>'.esc_html('% Change','bestbug').'</div>
							<div>'.esc_html('Volume 24H','bestbug').'</div>
							<div>'.esc_html('Last Market','bestbug').'</div>
						</div>
					</div> <!-- .features -->
					
					<div class="rc-comparisons-wrapper">
						<div class="rc-comparisons-columns">
							'.$dataCoins.'
						</div> <!-- .rc-comparisons-columns -->
					</div> <!-- .rc-comparisons-wrapper -->
					
					<ul class="rc-table-navigation">
						<li><a href="#0" class="prev">Prev</a></li>
						<li><a href="#0" class="next">Next</a></li>
					</ul>
				</div> <!-- .rc-comparisons-table -->
			</section> <!-- .rc-comparisons-comparison-table -->
			</div>';
		}
        
    }
	
	new BESTBUG_CRYPTO_COMPARISON_SHORTCODE();
}

