<?php
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! class_exists( 'BESTBUG_CRYPTO_SPARKCHARTS_SHORTCODE' ) ) {
	/**
	 * BESTBUG_CRYPTO_SPARKCHARTS_SHORTCODE Class
	 *
	 * @since	1.0
	 */
	class BESTBUG_CRYPTO_SPARKCHARTS_SHORTCODE {

		/**
		 * Constructor
		 *
		 * @return	void
		 * @since	1.0
		 */
		function __construct() {
			$this->init();
		}

		public function init() {
			
			add_shortcode( BESTBUG_CRYPTO_SPARKCHARTS_SHORTCODE, array( $this, 'shortcode' ) );
			if ( defined( 'WPB_VC_VERSION' ) && function_exists( 'vc_add_param' ) ) {
				$this->vc_shortcode();
			}

			if(is_admin()) {
				add_action( 'admin_enqueue_scripts', array( $this, 'adminEnqueueScripts' ) );
			}
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueueScripts' ) );

        }

		public function adminEnqueueScripts() {
			// wp_enqueue_style( 'css', BESTBUG_CRYPTO_URL . '/assets/admin/css/style.css' );
			// wp_enqueue_script( 'js', BESTBUG_CRYPTO_URL . '/assets/admin/js/script.js', array( 'jquery' ), '1.0', true );
			
		}

		public function enqueueScripts() {
			// wp_enqueue_style( 'css', BESTBUG_CRYPTO_URL . '/assets/css/style.css' );
			// wp_enqueue_script( 'js', BESTBUG_CRYPTO_URL . '/assets/js/script.js', array( 'jquery' ), '1.0', true );
		}
        
        public function vc_shortcode() {
			
        }
		
		public function shortcode( $atts, $content = null ) {

			shortcode_atts( array(
				'all_coins' => '',
				'only_coins' => '',
				'sparkchart_style' => '',
				'skin' => '',
				'shape' => '',
				'high_light' => '',
				'sparkchart_border' => '',
				'sparkchart_shadow' => ''
			), $atts );
			
			$dataCoins = '';
			$chartSkin = '';
			$container_class = array(
				'realcrypto',
				'realcrypto-sparkchart-wrap',
			);
			$time = time();
			$chart24h = get_option(BESTBUG_CRYPTO_PREFIX . 'chart24h');
			
			if(isset($atts['skin']) && !empty($atts['skin'])) {
				$container_class[] = 'rc-color-'.$atts['skin'];
				$chartSkin = $atts['skin'];
			}
			if(isset($atts['sparkchart_style']) && !empty($atts['sparkchart_style'])) {
				$container_class[] = 'rc-sparkchart-style-'.$atts['sparkchart_style'];
			}
			if(isset($atts['shape']) && !empty($atts['shape'])) {
				$container_class[] = 'rc-sparkchart-shape-'.$atts['shape'];
			}
			if(isset($atts['high_light']) && $atts['high_light'] == 'yes') {
				$container_class[] = 'rc-highlight';
			}
			if(isset($atts['sparkchart_shadow']) && $atts['sparkchart_shadow'] == 'yes') {
				$container_class[] = 'rc-sparkchart-shadow';
			}
			if(isset($atts['sparkchart_border']) && $atts['sparkchart_border'] == 'yes') {
				$container_class[] = 'rc-sparkchart-border';
			}
			
			if(isset($atts['only_coins']) && !empty($atts['only_coins'])) {
				$only_coins = explode(',', $atts['only_coins']);
				if(is_array($only_coins) && count($only_coins) > 0) {
					foreach ($only_coins as $key => $coins) {
						if(array_key_exists( $coins, BESTBUG_CRYPTO_HELPER::$alias)) {
							$coins = BESTBUG_CRYPTO_HELPER::$alias[$coins];
						}
						$dataChart24h = '';
						if(isset($chart24h[$coins]['time']) && $time - $chart24h[$coins]['time'] < 60 * 60 ) {
							$dataChart24h = '['.implode(',', $chart24h[$coins]['chart24h']).']';
						}
						
						if($atts['sparkchart_style'] == 'classic'):
							$dataCoins .= '<div class="rc-single-sparkchart-wrap" data-coin="'.$coins.'">
								<div class="rc-sparkchart-inside">
									<div class="rc-ic-coin">
										<span class="rc-image-'.$coins.'"></span>
									</div>	
									<div class="rc-pos-right">
										<div class="rc-top">
											<div class="rc-name">
												<span class="rc-coinname-'.$coins.'"></span>
												(<span class="rc-name-'.$coins.'"></span>)
											</div>
										</div>
										<div class="rc-info">
											<p class="rc-price">
												<span class="rc-highlight rc-wrap-PRICE-'.$coins.' rc-PRICE-'.$coins.'"></span>
												<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-up-color rc-arrow-up dashicons dashicons-arrow-up-alt"></span>
												<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-down-color rc-arrow-down dashicons dashicons-arrow-down-alt"></span>
											</p>
											<p class="rc-24h">
												<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-CHANGE24HOUR-'.$coins.'"></span>  
												(<span class="rc-wrap-CHANGE24HOURPCT-'.$coins.' rc-CHANGE24HOURPCT-'.$coins.'"></span>)
											</p>
										</div>
									</div>
								</div>
								<div class="rc-main-sparkchart">
									<span class="rc-sparkchart-'.$coins.'" data-color="'.$chartSkin.'"  data-sparkchart="'.$dataChart24h.'" data-sparkchart-coin="'.$coins.'"></span>
								</div>
							</div>';
						elseif($atts['sparkchart_style'] == 'advanced_1'):
							$dataCoins .= '<div class="rc-single-sparkchart-wrap" data-coin="'.$coins.'">
								<div class="rc-sparkchart-inside">
									<div class="rc-pos-left">
										<div class="rc-top">
											<div class="rc-name">
												<span class="rc-coinname-'.$coins.'"></span>
												(<span class="rc-name-'.$coins.'"></span>)
											</div>
										</div>
										<div class="rc-info">
											<p class="rc-price">
												<span class="rc-highlight rc-wrap-PRICE-'.$coins.' rc-PRICE-'.$coins.'"></span>
												<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-up-color rc-arrow-up dashicons dashicons-arrow-up-alt"></span>
												<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-down-color rc-arrow-down dashicons dashicons-arrow-down-alt"></span>
											</p>
											<p class="rc-24h">
												<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-CHANGE24HOUR-'.$coins.'"></span>  
												(<span class="rc-wrap-CHANGE24HOURPCT-'.$coins.' rc-CHANGE24HOURPCT-'.$coins.'"></span>)
											</p>
										</div>
									</div>
									<div class="rc-ic-coin">
										<span class="rc-image-'.$coins.'"></span>
									</div>	
								</div>
								<div class="rc-main-sparkchart">
									<span class="rc-sparkchart-'.$coins.'" data-color="'.$chartSkin.'"  data-sparkchart="'.$dataChart24h.'" data-sparkchart-coin="'.$coins.'"></span>
								</div>
							</div>';
						elseif($atts['sparkchart_style'] == 'advanced_2'):
							$dataCoins .= '<div class="rc-single-sparkchart-wrap" data-coin="'.$coins.'">
								<div class="rc-sparkchart-inside">
									<div class="rc-ic-coin">
										<span class="rc-image-'.$coins.'"></span>
									</div>	
									<div class="rc-pos-right">
										<div class="rc-top">
											<div class="rc-name">
												<span class="rc-coinname-'.$coins.'"></span>
												(<span class="rc-name-'.$coins.'"></span>)
											</div>
										</div>
										<div class="rc-info">
											<p class="rc-price">
												<span class="rc-highlight rc-wrap-PRICE-'.$coins.' rc-PRICE-'.$coins.'"></span>
												<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-up-color rc-arrow-up dashicons dashicons-arrow-up-alt"></span>
												<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-down-color rc-arrow-down dashicons dashicons-arrow-down-alt"></span>
											</p>
											<p class="rc-24h">
												<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-CHANGE24HOUR-'.$coins.'"></span>  
												(<span class="rc-wrap-CHANGE24HOURPCT-'.$coins.' rc-CHANGE24HOURPCT-'.$coins.'"></span>)
											</p>
										</div>
									</div>
								</div>
								<div class="rc-main-sparkchart">
									<span class="rc-sparkchart-'.$coins.'" data-color="'.$chartSkin.'"  data-sparkchart="'.$dataChart24h.'" data-sparkchart-coin="'.$coins.'" ></span>
								</div>
							</div>';
						elseif($atts['sparkchart_style'] == 'advanced_3'):
							$dataCoins .= '<div class="rc-single-sparkchart-wrap" data-coin="'.$coins.'">
								<span class="rc-image-'.$coins.'"></span>  
								<span class="rc-coinname-'.$coins.'"></span> 
								(<span class="rc-name-'.$coins.'"></span>) 
								<span class="rc-highlight rc-wrap-PRICE-'.$coins.' rc-PRICE-'.$coins.'"></span>
								<div class="rc-main-sparkchart">
									<span style="height: 21px; width: 120px; " class="rc-sparkchart-'.$coins.'" data-color="'.$chartSkin.'"  data-sparkchart="'.$dataChart24h.'" data-sparkchart-coin="'.$coins.'"></span>
								</div>
							</div>';
						elseif($atts['sparkchart_style'] == 'advanced_4'):
							$dataCoins .= '<div class="rc-single-sparkchart-wrap" data-coin="'.$coins.'">
								<div class="rc-sparkchart-inside">
									<div class="rc-ic-coin">
										<div class="rc-name-top">
											<span class="rc-image-'.$coins.'"></span>
											(<span class="rc-name-'.$coins.'"></span>)
										</div>
										<div class="rc-name">
											<span class="rc-coinname-'.$coins.'"></span>
										</div>
									</div>	
									<div class="rc-pos-right">
										<div class="rc-info">
											<p class="rc-price">
												<span class="rc-highlight rc-wrap-PRICE-'.$coins.' rc-PRICE-'.$coins.'"></span>
												<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-up-color rc-arrow-up dashicons dashicons-arrow-up-alt"></span>
												<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-down-color rc-arrow-down dashicons dashicons-arrow-down-alt"></span>
											</p>
											<p class="rc-24h">
												<span class="rc-wrap-CHANGE24HOUR-'.$coins.' rc-CHANGE24HOUR-'.$coins.'"></span>  
												(<span class="rc-wrap-CHANGE24HOURPCT-'.$coins.' rc-CHANGE24HOURPCT-'.$coins.'"></span>)
											</p>
										</div>
									</div>
								</div>
								<div class="rc-main-sparkchart">
									<span class="rc-sparkchart-'.$coins.'" data-color="'.$chartSkin.'"  data-sparkchart="'.$dataChart24h.'" data-sparkchart-coin="'.$coins.'"></span>
								</div>
							</div>';
						endif;
					}
				}
			}
			
			return '<div class="'.implode(" ", $container_class).'">
				<div class="realcrypto-sparkchart-inside">
					'.$dataCoins.'
	        	</div>
			</div>';
		}
        
    }
	
	new BESTBUG_CRYPTO_SPARKCHARTS_SHORTCODE();
}

